==> huaweicloudsdkbcs-3.0.46-py2.py3-none-any.whl: huaweicloudsdkbcs/v2/model/list_blockchains_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListBlockchainsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'blockchains': 'list[BlockchainInfo]'
    }

    attribute_map = {
        'blockchains': 'blockchains'
    }

    def __init__(self, blockchains=None):
        """ListBlockchainsResponse - a model defined in huaweicloud sdk"""
        
        super(ListBlockchainsResponse, self).__init__()

        self._blockchains = None
        self.discriminator = None

        if blockchains is not None:
            self.blockchains = blockchains

    @property
    def blockchains(self):
        """Gets the blockchains of this ListBlockchainsResponse.

        服务实例简要信息

        :return: The blockchains of this ListBlockchainsResponse.
        :rtype: list[BlockchainInfo]
        """
        return self._blockchains

    @blockchains.setter
    def blockchains(self, blockchains):
        """Sets the blockchains of this ListBlockchainsResponse.

        服务实例简要信息

        :param blockchains: The blockchains of this ListBlockchainsResponse.
        :type: list[BlockchainInfo]
        """
        self._blockchains = blockchains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBlockchainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbcs-3.0.52-py2.py3-none-any.whl: huaweicloudsdkbcs/v2/model/list_blockchains_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListBlockchainsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'blockchains': 'list[BlockchainInfo]'
    }

    attribute_map = {
        'blockchains': 'blockchains'
    }

    def __init__(self, blockchains=None):
        """ListBlockchainsResponse - a model defined in huaweicloud sdk"""
        
        super(ListBlockchainsResponse, self).__init__()

        self._blockchains = None
        self.discriminator = None

        if blockchains is not None:
            self.blockchains = blockchains

    @property
    def blockchains(self):
        """Gets the blockchains of this ListBlockchainsResponse.

        服务实例简要信息

        :return: The blockchains of this ListBlockchainsResponse.
        :rtype: list[BlockchainInfo]
        """
        return self._blockchains

    @blockchains.setter
    def blockchains(self, blockchains):
        """Sets the blockchains of this ListBlockchainsResponse.

        服务实例简要信息

        :param blockchains: The blockchains of this ListBlockchainsResponse.
        :type: list[BlockchainInfo]
        """
        self._blockchains = blockchains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBlockchainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
